function resInflamM3()
% resInflamM1 resproduces figure 13 from
% Dunster et al (2014) Resolution of inflammation: a mathematical model of neutrophil and macrophage interactions. Bulletin of mathematical biology, 76(8), pp.1953-1980.
% 
% 2017-01-13
% Joanne L Dunster @CardioMaths
% 
% Please cite the above mentioned paper if you use this code 

clear; close all; clc;
format short;
tic

%initial conditions
%------------------
u10=0; u20=0; u30=0; u40=0; u50=0;
u0=[u10 u20 u30 u40 u50];
disp({'Initial conditions'});
disp({'n1',u10, 'n2', u20, 'm',u30,'c',u40, 'g',u50});

%Length of damage, select 1 (healthy) or 4 (unhealthy)
cyc=4;
dam=cyc*pi;

%Time to solve odes
estart=0.1; etime=10000;
tspan = [estart etime];
disp({'Solved to :', etime, 'mins'});


%nondimensional parameter values 

%Model 1 parameters (taken from Table 4)
alpha=0.05; 
nnu=0.1; 
nbetaa=0.1; 
ngm=0.01; 
nphi=0.001; 
nga=1; 

%Model 2 parameters
nkn=0.01; 
nbetan=0.1;

%Model 3 parameters
nbetac=0.12; 
nbetag=0.01; 
ngg=1; 
nkg=0.01; 

%Adjustments for Figure 13
%Damped oscillations (plots for 3rd row)
nphi=0.080;
%Solid oscillations
nkg=0.65; 


%ODE solver
%----------
options=odeset('RelTol',1e-8,'AbsTol',1e-10);

[t,u] = ode45(@eqsolv,tspan,u0,options);


%plotting figures
%----------------

figure;  
semilogx(t,u(:,1),'-','LineWidth',2');
hold on;
semilogx(t,u(:,2),'--','LineWidth',2');
semilogx(t,u(:,3),'-.','LineWidth',2');
xlim([estart,etime]);
if cyc==1
   ylim([0,0.08]); %healthy
else
   ylim([0,110]); %unhealthy
end

figure;
semilogx(t,u(:,4),'-','LineWidth',2');
hold on;
semilogx(t,u(:,5),'--','LineWidth',2');
xlim([estart,etime]);
if cyc==1
   ylim([0,0.025]); %healthy
else
   ylim([0,1.1]); %unhealthy
end

%--------------------------------------------------------------------------
%Full governing equations
    function du=eqsolv(t,u)
 
        du=zeros(5,1);
        f=fc(t);
         
        du(1)= u(4)/(1+u(5)) - nnu*u(1)*((1+u(5)/nbetag)/(1+u(4)/nbetac));
        du(2)= nnu*u(1)*((1+u(5)/nbetag)/(1+u(4)/nbetac)) - nga*u(2) - nphi*u(3)*u(2);
        du(3)= u(4) - ngm*u(3);
        du(4)= alpha*f + nkn*u(1)^2/(nbetan^2 + u(1)^2) + nga*u(2)^2/(nbetaa^2 + u(2)^2) - u(4);
        du(5)= nkg*nphi*u(3)*u(2) - ngg*u(5);
          
    end


%-----------------------------------------------------------------------
%Damage function
     function y=fc(fct)
 
         y=sin(fct).^2;
         y=y.*(fct<dam);
        
     end

end

