function resInflamM3Therapy()
% resInflamM1 resproduces figures 15 from
% Dunster et al (2014) Resolution of inflammation: a mathematical model of neutrophil and macrophage interactions. Bulletin of mathematical biology, 76(8), pp.1953-1980.
% 
% 2017-01-13
% Joanne L Dunster @CardioMaths
% 
% Please cite the above mentioned paper if you use this code 

clear; close all; clc;
format short;
tic

%initial conditions
%------------------
u10=0; u20=0; u30=0; u40=0; u50=0;
u0=[u10 u20 u30 u40 u50];
disp({'Initial conditions'});
disp({'n1',u10, 'n2', u20, 'm',u30,'c',u40, 'g',u50});

%Length of damage, select 1 (healthy) or 4 (unhealthy)
cyc=4;
dam=cyc*pi;

%time of therapeutic manipulation
ther1=20*pi; 
ther2=50*pi;

%Time to solve odes
estart=0.1; etime=10000;
tspan = [estart etime];
disp({'Solved to :', etime, 'mins'});


%nondimensional parameter values 

%Model 1 parameters (taken from Table 4)
alpha=0.05; 
nnu=0.1; 
nbetaa=0.1; 
ngm=0.01; 
nphi=0.001; 
nga=1; 

%Model 2 parameters
nkn=0.01; 
nbetan=0.1;

%Model 3 parameters
nbetac=0.12; 
nbetag=0.01; 
ngg=1; 
nkg=0.01; 

%ODE solver
%----------
options=odeset('RelTol',1e-8,'AbsTol',1e-10);

%Untreated solutions
[to,uo] = ode45(@eqsolv,tspan,u0,options);

%Treated solutions
[t,u] = ode45(@eqsolvtr,tspan,u0,options);


%plotting figures
%----------------

figure;  
semilogx(to,uo(:,1),'-','LineWidth',1');
hold on;
semilogx(to,uo(:,2),'--','LineWidth',1');
semilogx(to,uo(:,3),'-.','LineWidth',1');

semilogx(t,u(:,1),'-','LineWidth',2');
hold on;
semilogx(t,u(:,2),'--','LineWidth',2');
semilogx(t,u(:,3),'-.','LineWidth',2');

xlim([estart,etime]);
ylim([0,110]); %unhealthy

figure;
semilogx(t,u(:,4),'-','LineWidth',2');
hold on;
semilogx(t,u(:,5),'--','LineWidth',2');
xlim([estart,etime]);
ylim([0,1.1]); %unhealthy

%--------------------------------------------------------------------------
%Full governing equations
    function du=eqsolv(t,u)
 
        du=zeros(5,1);
        f=fc(t);
         
        du(1)= u(4)/(1+u(5)) - nnu*u(1)*((1+u(5)/nbetag)/(1+u(4)/nbetac));
        du(2)= nnu*u(1)*((1+u(5)/nbetag)/(1+u(4)/nbetac)) - nga*u(2) - nphi*u(3)*u(2);
        du(3)= u(4) - ngm*u(3);
        du(4)= alpha*f + nkn*u(1)^2/(nbetan^2 + u(1)^2) + nga*u(2)^2/(nbetaa^2 + u(2)^2) - u(4);
        du(5)= nkg*nphi*u(3)*u(2) - ngg*u(5);
          
    end


%-----------------------------------------------------------------------
%Damage function
     function y=fc(fct)
 
         y=sin(fct).^2;
         y=y.*(fct<dam);
        
     end

 %--------------------------------------------------------------------------
    function du=eqsolvtr(t,u)

         du=zeros(5,1);
         f=fc(t);

         %Manipulating parameter phi (different values are used in left, central and
         %right panels)
         %trphi=12000; %left panels (strong)
         %trphi=2500; %central panels (medium)
         trphi=40; %right panels (low)
         vphi=fphi(t,trphi);

         %Manipulating rate of prod of inflam mediator (only required for central panels)
         %vkg=fkg(t);
         vkg=nkg;

         %Manipulating rate of apoptosis (only required for right panels)
         vnu=fnu(t);
         %vnu=nnu;

         du(1)= u(4)/(1+u(5)) - vnu*u(1)*((1+u(5)/nbetag)/(1+u(4)/nbetac));
         du(2)= nnu*u(1)*((1+u(5)/nbetag)/(1+u(4)/nbetac)) - nga*u(2) - vphi*u(3)*u(2);
         du(3)= u(4) - ngm*u(3);
         du(4)= alpha*f + nkn*u(1)^2/(nbetan^2 + u(1)^2) + nga*u(2)^2/(nbetaa^2 + u(2)^2) - u(4);
         du(5)= vkg*nphi*u(3)*u(2) - ngg*u(5);
          
    end

%-----------------------------------------------------------------------
     function y=fphi(fp,tphi)
         %Manipulating phi, 
         %1200 to heal 
         y=nphi;
         if fp>ther1 && fp<ther2
            y=y+nphi*tphi; 
         end
     end
%-----------------------------------------------------------------------
          function y=fkg(fp)
         %Manipulating nu
         y=nkg;
         if fp>ther1 && fp<ther2
            y=y+nkg*250;
         end
      end
%-----------------------------------------------------------------------
       function y=fnu(fp)
         %Manipulating nu
         y=nnu;
         if fp>ther1 && fp<ther2
            y=y+nnu*4;
         end
       end

end

